2013-04-16  joke2k <joke2k@gmail.com>

  * environ/environ.py, environ/test.py, environ/test_env.txt: add advanced
  float parsing (comma and dot symbols to separate thousands and decimals)

  * README.rst, docs/index.rst: fix TYPO in documentation
